# frozen_string_literal: true

# CarrierWave Secure - Licensed under LGPL-3.0

load 'carrierwave/secure/tasks/generate_key.rake'

require 'carrierwave'
require 'carrierwave/secure/configuration'
require 'carrierwave/secure/cipher'
require 'carrierwave/secure/abstract_file'
require 'carrierwave/secure/encrypted_file'
require 'carrierwave/secure/decrypted_file'
require 'carrierwave/secure/uploader'
require 'carrierwave/secure/mount'

module CarrierWave
  # Base library module
  module Secure
    # Uses AES in GCM mode
    def self.cipher
      secure_key = CarrierWave::Uploader::Base.send(:secure_key)
      return CarrierWave::Secure::Cipher.new(nil) if secure_key.nil?

      @cipher ||= CarrierWave::Secure::Cipher.new(Base64.decode64(secure_key))
    end
  end
end
