# frozen_string_literal: true

# CarrierWave Secure - Licensed under LGPL-3.0

module CarrierWave
  module Secure
    # Intercepts calls to `CarrierWave::Mount` methods and decorates uploader if `secure` option is
    # set to `true`.
    module Mount
      def mount_base(column, uploader = nil, options = {}, &block)
        return super unless options[:secure] == true

        uploader_decorator = CarrierWave::Uploader::Secure[uploader]
        super(column, uploader_decorator, options, &block)
      end
    end
  end
end
# Put `CarrierWave::Secure::Mount` before `CarrierWave::Mount` in the ancestors chain.
CarrierWave::Mount.prepend(CarrierWave::Secure::Mount)
